# Core API

::: d3_bridge.core.Chart
    options:
      show_source: false
      members:
        - chart_type
        - __init__
        - fields
        - extra_js
        - set_theme
        - set_margin
        - to_config
        - to_json
